@@ -5,6 +5,7 @@ from anytree.node.util import _repr
 from euphorie import MessageFactory as _
 from euphorie.client import utils
 from euphorie.client.country import IClientCountry
+from euphorie.client.interfaces import IClientSkinLayer
 from euphorie.client.model import get_current_account
 from euphorie.client.sector import IClientSector
 from euphorie.content.survey import ISurvey
@@ -17,6 +18,7 @@ from Products.CMFPlone.utils import safe_unicode
 from Products.Five import BrowserView
 from z3c.saconfig import Session
 from zExceptions import Unauthorized
+from zope.interface import directlyProvides
 
 import six
 
@@ -26,7 +28,7 @@ logger = getLogger(__name__)
 
 def capitalize(text):
     if text:
-        return u"{0}{1}".format(text[0].upper(), text[1:])
+        return "{0}{1}".format(text[0].upper(), text[1:])
 
 
 class Node(NodeMixin):
@@ -141,7 +143,7 @@ class SurveyTemplatesMixin(object):
                 if not isinstance(categories, list):
                     categories = [categories]
                 if not categories:
-                    categories = [None]
+                    categories = ["None"]
                 for category in categories:
                     survey_items.append((category, survey, id))
         return sorted(survey_items, key=lambda x: (x[0], x[1].title))
@@ -150,7 +152,6 @@ class SurveyTemplatesMixin(object):
 class SessionsView(BrowserView, SurveyTemplatesMixin):
 
     variation_class = "variation-dashboard"
-    _portlet_names = ["portlet-my-ras", "portlet-available-tools"]
     form_action_name = "dashboard-switcher"
 
     @property
@@ -163,6 +164,13 @@ class SessionsView(BrowserView, SurveyTemplatesMixin):
     def survey_session_model(self):
         return self.webhelpers.survey_session_model
 
+    @property
+    def _portlet_names(self):
+        names = ["portlet-my-ras", "portlet-available-tools"]
+        if self.webhelpers.use_training_module:
+            names.append("portlet-my-trainings")
+        return names
+
     @property
     @memoize
     def portlets(self):
@@ -232,7 +240,7 @@ class SessionsView(BrowserView, SurveyTemplatesMixin):
             self.request.response.redirect(context.absolute_url())
             return
 
-        title = info.get("title", u"").strip()
+        title = info.get("title", "").strip()
 
         survey_view = api.content.get_view("index_html", survey, self.request)
         survey_session = survey_view.create_survey_session(title, account)
@@ -257,7 +265,7 @@ class SessionsView(BrowserView, SurveyTemplatesMixin):
 
     def tool_byline(self):
         title = api.portal.translate(
-            _("title_tool", default=u"OiRA - Online interactive Risk Assessment")
+            _("title_tool", default="OiRA - Online interactive Risk Assessment")
         )
         return title.split("-")[-1].strip()
 
@@ -332,7 +340,7 @@ class SessionBrowserNavigator(BrowserView):
             return ""
         if len(searchable_text) < 3:
             return ""
-        return u"%{}%".format(safe_unicode(searchable_text))
+        return "%{}%".format(safe_unicode(searchable_text))
 
     @memoize
     def leaf_groups(self, groupid=None):
@@ -369,6 +377,10 @@ class Assessments(BrowserView):
     def form_action_name(self):
         return self.__name__
 
+    @property
+    def template(self):
+        return self.index
+
     @property
     @memoize
     def sessions(self):
@@ -534,6 +546,16 @@ class MyRAsPortlet(PortletBase):
             return "2"
         return "3"
 
+    @property
+    def assessments_list_macro(self):
+        """Get the listing macro from the assessments template"""
+        request = self.request.clone()
+        # This is needed, since the view might be subclassed and therefore
+        # associated with a different skin-layer.
+        directlyProvides(request, IClientSkinLayer)
+        view = api.content.get_view("assessments", self.context, request)
+        return view.template.macros["assessments_list"]
+
     @property
     @memoize_contextless
     def hide_archived(self):
@@ -561,7 +583,7 @@ class MyRAsPortlet(PortletBase):
     @property
     def label_start_session(self):
         label = api.portal.translate(
-            _(u"link_start_session", default=u"Start a new risk assessment")
+            _("link_start_session", default="Start a new risk assessment")
         )
         return capitalize(label)
 
