@@ -88,16 +88,44 @@ class Login(BrowserView):
                 120 * 24 * 60 * 60
             )  # noqa: E501
 
-    def transferGuestSession(self, account_id):
-        """Transfer session(s) from guest account to an existing user account"""
-        if not account_id:
+    def transferGuestSession(self):
+        """Transfer session(s) from guest account to an existing user account
+
+        The guest account is expected to go the login form as an authenticated user.
+
+        For this reason we can know from the session plugin who he is even
+        if during the request process we are now logged in as a new user.
+        """
+        plugin = self.context.acl_users.session
+        old_credentials = plugin.authenticateCredentials(
+            plugin.extractCredentials(self.request)
+        )
+        if old_credentials is None:
+            # We came here as anonymous user, no need to proceed
             return
-        account = get_current_account()
+
+        old_authenticated_account_id = old_credentials[0]
+
+        if (
+            Session.query(model.Account)
+            .filter(
+                model.Account.account_type == config.GUEST_ACCOUNT,
+                model.Account.id == old_authenticated_account_id,
+            )
+            .first()
+        ) is None:
+            # We check that the previously authenticated user was actually
+            # a guest account that has been converted.
+            # This prevents that a regular logged in user A logs in as B
+            # and then all the sessions are transferred to B
+            return
+
+        new_account = get_current_account()
         sessions = Session.query(model.SurveySession).filter(
-            model.SurveySession.account_id == account_id
+            model.SurveySession.account_id == old_authenticated_account_id
         )
         for session in sessions:
-            session.account_id = account.id
+            session.account_id = new_account.id
 
     def is_valid_password(self, password):
         if (
@@ -114,9 +142,9 @@ class Login(BrowserView):
             return _(
                 "error_password_policy_violation",
                 default=(
-                    u"The password needs to be at least 12 characters long and "
-                    u"needs to contain at least one lower case letter, one upper "
-                    u"case letter and one digit."
+                    "The password needs to be at least 12 characters long and "
+                    "needs to contain at least one lower case letter, one upper "
+                    "case letter and one digit."
                 ),
             )
 
@@ -127,19 +155,19 @@ class Login(BrowserView):
         loginname = form.get("email")
         if not loginname:
             self.errors["email"] = _(
-                "error_missing_email", default=u"Please enter your email address"
+                "error_missing_email", default="Please enter your email address"
             )
         elif not EMAIL_RE.match(loginname):
             self.errors["email"] = _(
-                "error_invalid_email", default=u"Please enter a valid email address"
+                "error_invalid_email", default="Please enter a valid email address"
             )
         if not form.get("password1"):
             self.errors["password"] = _(
-                "error_missing_password", default=u"Please enter a password"
+                "error_missing_password", default="Please enter a password"
             )
         elif form.get("password1") != form.get("password2"):
             self.errors["password"] = _(
-                "error_password_mismatch", default=u"Passwords do not match"
+                "error_password_mismatch", default="Passwords do not match"
             )
         else:
             policy_error = self.check_password_policy(form.get("password1"))
@@ -148,8 +176,8 @@ class Login(BrowserView):
         if not form.get("terms"):
             self.errors["terms"] = _(
                 "error_terms_not_accepted",
-                default=u"An accout can only be created for you if you accept the "
-                u"terms and conditions.",
+                default="An accout can only be created for you if you accept the "
+                "terms and conditions.",
             )
 
         if self.errors:
@@ -169,7 +197,7 @@ class Login(BrowserView):
         if account:
             self.errors["email"] = _(
                 "error_email_in_use",
-                default=u"An account with this email address already exists.",
+                default="An account with this email address already exists.",
             )
             return False
 
@@ -177,13 +205,12 @@ class Login(BrowserView):
         if pm.getMemberById(loginname) is not None:
             self.errors["email"] = _(
                 "error_email_in_use",
-                default=u"An account with this email address already exists.",
+                default="An account with this email address already exists.",
             )
             return False
 
-        guest_account_id = self.request.form.get("guest_account_id")
-        if guest_account_id:
-            account = get_current_account()
+        account = get_current_account()
+        if account and account.account_type == config.GUEST_ACCOUNT:
             account.loginname = loginname
             account.password = form.get("password1")
             account.account_type = config.CONVERTED_ACCOUNT
@@ -194,12 +221,11 @@ class Login(BrowserView):
                 mapping={"email": loginname},
             )
             api.portal.show_message(msg, self.request, "success")
-
         else:
             account = model.Account(
                 loginname=loginname, password=form.get("password1"), tc_approved=1
             )
-        Session().add(account)
+            Session().add(account)
         log.info("Registered new account %s", loginname)
         v_url = urlsplit(self.request.URL + "/success").path.replace("@@", "")
         trigger_extra_pageview(self.request, v_url)
@@ -211,14 +237,7 @@ class Login(BrowserView):
 
         form = self.request.form
 
-        came_from = form.get("came_from")
-        if came_from:
-            if isinstance(came_from, list):
-                # If came_from is both in the querystring and the form data
-                came_from = came_from[0]
-        else:
-            # Set to country url
-            came_from = self.webhelpers.country_url
+        came_from = self.webhelpers.get_came_from(default=self.webhelpers.country_url)
         self.setLanguage(came_from)
 
         account = get_current_account()
@@ -239,7 +258,7 @@ class Login(BrowserView):
                     isinstance(account, model.Account)
                     and account.getUserName() == form.get("__ac_name", "").lower()
                 ):
-                    self.transferGuestSession(form.get("guest_account_id"))
+                    self.transferGuestSession()
                     self.login(account, bool(self.request.form.get("remember")))
                     v_url = urlsplit(self.request.URL + "/success").path.replace(
                         "@@", ""
@@ -362,13 +381,10 @@ class CreateTestSession(Tryout):
             "euphorie.allow_guest_accounts", default=False
         )
         context = aq_inner(self.context)
-        came_from = self.request.form.get("came_from")
-        if came_from:
-            if isinstance(came_from, list):
-                # If came_from is both in the querystring and the form data
-                came_from = came_from[0]
-        else:
-            came_from = context.absolute_url()
+        webhelpers = api.content.get_view(
+            name="webhelpers", context=self.context, request=self.request
+        )
+        came_from = webhelpers.get_came_from(default=context.absolute_url())
         self.register_url = "%s/@@login?%s#registration" % (
             context.absolute_url(),
             urlencode({"came_from": came_from}),
@@ -379,8 +395,8 @@ class CreateTestSession(Tryout):
                 flash = IStatusMessage(self.request).addStatusMessage
                 flash(
                     _(
-                        u"Starting a test session is not available in this OiRA "
-                        u"application."
+                        "Starting a test session is not available in this OiRA "
+                        "application."
                     ),
                     "error",
                 )
