@@ -51,35 +51,56 @@ class RiskBase(BrowserView):
     style_buttons = None
 
     def __call__(self):
-        self.delete_confirmation = api.portal.translate(
+        pass
+
+    @property
+    @memoize
+    def delete_confirmation(self):
+        return api.portal.translate(
             _(
-                u"Are you sure you want to delete this measure? This action can "
-                u"not be reverted."
+                "Are you sure you want to delete this measure? This action can "
+                "not be reverted."
             )
         )
-        self.override_confirmation = api.portal.translate(
+
+    @property
+    @memoize
+    def override_confirmation(self):
+        return api.portal.translate(
             _(
-                u"The current text in the fields 'Action plan', 'Prevention plan' and "
-                u"'Requirements' of this measure will be overwritten. "
-                u"This action cannot be reverted. Are you sure you want to continue?"
+                "The current text in the fields 'Action plan', 'Prevention plan' and "
+                "'Requirements' of this measure will be overwritten. "
+                "This action cannot be reverted. Are you sure you want to continue?"
             )
         )
-        self.message_date_before = api.portal.translate(
+
+    @property
+    @memoize
+    def message_date_after(self):
+        return api.portal.translate(
             _(
-                u"error_validation_before_end_date",
-                default=u"This date must be on or before the end date.",
+                "error_validation_after_start_date",
+                default="This date must be on or after the start date.",
             )
         )
-        self.message_date_after = api.portal.translate(
+
+    @property
+    @memoize
+    def message_positive_number(self):
+        return api.portal.translate(
             _(
-                u"error_validation_after_start_date",
-                default=u"This date must be on or after the start date.",
+                "error_validation_positive_whole_number",
+                default="This value must be a positive whole number.",
             )
         )
-        self.message_positive_number = api.portal.translate(
+
+    @property
+    @memoize
+    def message_date_before(self):
+        return api.portal.translate(
             _(
-                u"error_validation_positive_whole_number",
-                default=u"This value must be a positive whole number.",
+                "error_validation_before_end_date",
+                default="This date must be on or before the end date.",
             )
         )
 
@@ -170,20 +191,73 @@ class RiskBase(BrowserView):
 
     def extract_plans_from_request(self):
         """Create new ActionPlan objects by parsing the Request."""
+        context = aq_inner(self.context)
+        form = self.request.form
+        context_measures = context.standard_measures + context.custom_measures
+        if form.get("handle_training_measures"):
+            # Gather all (database-) ids of the active measures. That means, those
+            # measures where the checkboxes are ticked in the training configuration.
+            # Remember: a measure that has been deselected (checkbox unticked)
+            # does not appear in the REQUEST
+            active_measures = []
+            for entry in form:
+                if entry.startswith("training-measure") and entry.find("-") >= 0:
+                    measure_id = entry.split("-")[-1]
+                    active_measures.append(measure_id)
+            # Get the ids of all measures-in-place and map them to the solution-ids
+            # Remember: the solution-id is the ZODB-id of the respective solution
+            # inside the risk in the CMS. We us it to identify the standard measures.
+            # The custom measures will not have a solution-id
+            all_measures = {
+                str(measure.id): measure.solution_id for measure in context_measures
+            }
+            # The following 2 mappings will be used if the handling of measures in
+            # place is also part of this request (further down)
+            # Make a mapping of solution-id to used-in-training state for the
+            # standard measures
+            saved_solutions = {
+                v: k in active_measures for (k, v) in all_measures.items() if v
+            }
+            # Make a mapping of database-id to used-in-training state for the
+            # custom measures
+            saved_custom_measures = {
+                k: k in active_measures for (k, v) in all_measures.items() if not v
+            }
+        else:
+            # The following 2 mappings will be used if the handling of measures in
+            # place is also part of this request (further down)
+            # We do not have training configuration in the REQUEST. We need
+            # to build the mapping of solution-id to used-in-training state
+            # via the information stored in the the database...
+            saved_solutions = {
+                plan.solution_id: plan.used_in_training
+                for plan in self.context.standard_measures
+            }
+            # ... and also for the custom measures
+            saved_custom_measures = {
+                str(plan.id): plan.used_in_training
+                for plan in self.context.custom_measures
+            }
         new_plans = []
         added = 0
         updated = 0
         existing_plans = {}
-        context = aq_inner(self.context)
-        for plan in context.standard_measures + context.custom_measures:
-            existing_plans[str(plan.id)] = plan
-        form = self.request.form
         form["action_plans"] = []
+        for plan in context_measures:
+            existing_plans[str(plan.id)] = plan
         for i in range(0, len(form.get("measure", []))):
             measure = dict([p for p in form["measure"][i].items() if p[1].strip()])
             form["action_plans"].append(measure)
             if len(measure):
                 plan_type = measure.get("plan_type", "measure_custom")
+                if plan_type == "measure_standard":
+                    used_in_training = saved_solutions.get(
+                        measure.get("solution_id"), True
+                    )
+                else:
+                    used_in_training = saved_custom_measures.get(
+                        measure.get("id"), True
+                    )
                 solution_id = measure.get("solution_id", None)
                 if plan_type == "measure_standard" and not form.get(
                     "sm-%s" % solution_id
@@ -247,6 +321,7 @@ class RiskBase(BrowserView):
                         planning_end=p_end,
                         plan_type=plan_type,
                         solution_id=solution_id,
+                        used_in_training=used_in_training,
                     )
                 )
         removed = len(existing_plans)
@@ -263,7 +338,7 @@ class RiskBase(BrowserView):
                 return api.portal.translate(
                     _(
                         "action_measures_true_solutions_true",
-                        default=u"Select or describe any further measure to reduce the risk.",  # noqa: E501  # noqa: E501
+                        default="Select or describe any further measure to reduce the risk.",  # noqa: E501  # noqa: E501
                     )
                 )
             # Case: measures-in-place==true, solutions==false
@@ -271,7 +346,7 @@ class RiskBase(BrowserView):
                 return api.portal.translate(
                     _(
                         "action_measures_true_solutions_false",
-                        default=u"Describe any further measure to reduce the risk.",
+                        default="Describe any further measure to reduce the risk.",
                     )
                 )
         else:
@@ -280,7 +355,7 @@ class RiskBase(BrowserView):
                 return api.portal.translate(
                     _(
                         "action_measures_false_solutions_true",
-                        default=u"Select or describe the specific measures required to reduce the risk.",  # noqa: E501
+                        default="Select or describe the specific measures required to reduce the risk.",  # noqa: E501
                     )
                 )
             # Case: measures-in-place==false, solutions==false
@@ -288,7 +363,7 @@ class RiskBase(BrowserView):
                 return api.portal.translate(
                     _(
                         "action_measures_false_solutions_false",
-                        default=u"Describe the specific measures required to reduce the risk.",  # noqa: E501
+                        default="Describe the specific measures required to reduce the risk.",  # noqa: E501
                     )
                 )
 
@@ -299,6 +374,21 @@ class RiskBase(BrowserView):
             _next = _next.pop()
         return _next
 
+    @property
+    def notes_placeholder(self):
+        if self.webhelpers.use_training_module:
+            return _(
+                "placeholder_comment_field_training",
+                default="These notes will be visible in the report and the training. "
+                "Use it for anything else you might want to write about this risk.",
+            )
+        else:
+            return _(
+                "placeholder_comment_field",
+                default="These notes will be visible in the report. Use it for "
+                "anything else you might want to write about this risk.",
+            )
+
 
 class IdentificationView(RiskBase):
     """A view for displaying a question in the identification phase"""
@@ -326,7 +416,7 @@ class IdentificationView(RiskBase):
         "frequency": None,
         "severity": None,
         "priority": None,
-        "comment": u"",
+        "comment": "",
         "training_notes": None,
         "custom_description": None,
     }
@@ -370,7 +460,7 @@ class IdentificationView(RiskBase):
     @property
     @memoize
     def skip_evaluation(self):
-        """ Default value is False, but it can be tweaked in certain conditions"""
+        """Default value is False, but it can be tweaked in certain conditions"""
         if self.italy_special and (
             (
                 self.risk
@@ -393,7 +483,7 @@ class IdentificationView(RiskBase):
 
     @property
     def action_plan_condition(self):
-        """ In what circumstances will the integrated Action Plan be shown"""
+        """In what circumstances will the integrated Action Plan be shown"""
         condition = "condition: answer=no"
         if not self.is_custom_risk and (
             self.risk.type == "top5" or self.risk.risk_always_present
@@ -403,6 +493,12 @@ class IdentificationView(RiskBase):
         return condition
 
     def __call__(self):
+        # Render the page only if the user has edit rights,
+        # otherwise redirect to the start page of the session.
+        if not self.webhelpers.can_edit_session:
+            return self.request.response.redirect(
+                self.context.aq_parent.absolute_url() + "/@@start"
+            )
         super(IdentificationView, self).__call__()
         self.check_render_condition()
 
@@ -438,49 +534,11 @@ class IdentificationView(RiskBase):
                     self.context.action_plans.extend(new_plans)
                     changed = changes or changed
 
-            if self.webhelpers.use_training_module:
-                if reply.get("handle_training_notes"):
-                    self.context.training_notes = reply.get("training_notes")
-                    changed = True
-                # Case: the user has selected or de-selected a measure
-                # from the training slide
-                if reply.get("handle_training_measures_for"):
-                    # Gather all ids of the active measures, that means,
-                    # where the checkboxes are ticked.
-                    # Remember: a measure that has been deselected (checkbox unticked)
-                    # does not appear in the REQUEST
-                    active_measures = set()
-                    for entry in reply:
-                        if entry.startswith("measure") and entry.find("-") >= 0:
-                            measure_id = entry.split("-")[-1]
-                            active_measures.add(measure_id)
-                    # Get the ids of all measures-in-place
-                    all_measures = set(
-                        [
-                            str(measure.id)
-                            for measure in list(self.context.in_place_standard_measures)
-                            + list(self.context.in_place_custom_measures)
-                        ]
-                    )
-                    # All measures that are not present in the REQUEST are deselected
-                    deselected_measures = all_measures - active_measures
-                    if active_measures:
-                        session.execute(
-                            "UPDATE action_plan set used_in_training=true where id in ({ids})".format(  # noqa: E501
-                                ids=",".join(active_measures)
-                            )
-                        )
-                    if deselected_measures:
-                        session.execute(
-                            "UPDATE action_plan set used_in_training=false where id in ({ids})".format(  # noqa: E501
-                                ids=",".join(deselected_measures)
-                            )
-                        )
-                    changed = True
-
             # This only happens on custom risks
             if reply.get("handle_custom_description"):
-                self.context.custom_description = reply.get("custom_description")
+                self.context.custom_description = self.webhelpers.check_markup(
+                    reply.get("custom_description")
+                )
 
             if reply.get("title"):
                 self.context.title = reply.get("title")
@@ -547,7 +605,7 @@ class IdentificationView(RiskBase):
         # any answer-related data, since the request might have come
         # from a sub-form.
         if answer:
-            self.context.comment = reply.get("comment")
+            self.context.comment = self.webhelpers.check_markup(reply.get("comment"))
             self.context.postponed = answer == "postponed"
             if self.context.postponed:
                 self.context.identification = None
@@ -563,18 +621,94 @@ class IdentificationView(RiskBase):
     def set_measure_data(self, reply, session):
 
         changed = False
-        if self.use_existing_measures and reply.get("handle_measures_in_place"):
-            new_measures = []
-            saved_solutions = {
+        # Case: the user has selected or de-selected a measure
+        # from the training configuration
+        if reply.get("handle_training_measures"):
+            # Gather all (database-) ids of the active measures. That means, those
+            # measures where the checkboxes are ticked in the training configuration.
+            # Remember: a measure that has been deselected (checkbox unticked)
+            # does not appear in the REQUEST
+            active_measures_in_place = []
+            active_measures_planned = []
+            for entry in reply:
+                if (
+                    entry.startswith("training-measure-in-place")
+                    and entry.find("-") >= 0
+                ):
+                    measure_id = entry.split("-")[-1]
+                    active_measures_in_place.append(measure_id)
+                elif (
+                    entry.startswith("training-measure-planned")
+                    and entry.find("-") >= 0
+                ):
+                    measure_id = entry.split("-")[-1]
+                    active_measures_planned.append(measure_id)
+            # Get the ids of all measures-in-place and map them to the solution-ids
+            # Remember: the solution-id is the ZODB-id of the respective solution
+            # inside the risk in the CMS. We us it to identify the standard measures.
+            # The custom measures will not have a solution-id
+            all_in_place_measures = {
+                str(measure.id): measure.solution_id
+                for measure in list(self.context.in_place_standard_measures)
+                + list(self.context.in_place_custom_measures)
+            }
+            all_planned_measures = {
+                str(measure.id): measure.solution_id
+                for measure in list(self.context.standard_measures)
+                + list(self.context.custom_measures)
+            }
+            # The following 2 mappings will be used if the handling of measures in
+            # place is also part of this request (further down)
+            # Make a mapping of solution-id to used-in-training state for the
+            # standard measures
+            saved_in_place_solutions = {
+                v: k in active_measures_in_place
+                for (k, v) in all_in_place_measures.items()
+                if v
+            }
+            # Make a mapping of database-id to used-in-training state for the
+            # custom measures
+            saved_in_place_custom_measures = {
+                k: k in active_measures_in_place
+                for (k, v) in all_in_place_measures.items()
+                if not v
+            }
+            # Additionally store the (database) ids of all measures that have been
+            # deactivated. In case we do not handle measures in place in this
+            # request further down, we need to make sure that those measues get
+            # set to used_in_training=False at the end of this method
+            deselected_in_place_measures = [
+                k for k in all_in_place_measures if k not in active_measures_in_place
+            ]
+            deselected_planned_measures = [
+                k for k in all_planned_measures if k not in active_measures_planned
+            ]
+        else:
+            # The following 2 mappings will be used if the handling of measures in
+            # place is also part of this request (further down)
+            # We do not have training configuration in the REQUEST. We need
+            # to build the mapping of solution-id to used-in-training state
+            # via the information stored in the the database...
+            saved_in_place_solutions = {
                 plan.solution_id: plan.used_in_training
                 for plan in self.context.in_place_standard_measures
             }
+            # ... and also for the custom measures
+            saved_in_place_custom_measures = {
+                str(plan.id): plan.used_in_training
+                for plan in self.context.in_place_custom_measures
+            }
+            deselected_in_place_measures = deselected_planned_measures = []
+            active_measures_in_place = active_measures_planned = []
+
+        if reply.get("handle_measures_in_place"):
+            new_measures = []
             # First, check which of the standard solutions were selected
             for solution in self.solutions_provided_by_tool:
                 # If the solution was already added as a measure, retrieve the info
                 # whether it was de-selected for the training, so that we don't
                 # forcefully activate all measures for the training again.
-                used_in_training = saved_solutions.get(solution.id, True)
+                used_in_training = saved_in_place_solutions.get(solution.id, True)
                 if reply.get("measure-standard-%s" % solution.id):
                     new_measures.append(
                         model.ActionPlan(
@@ -607,14 +741,22 @@ class IdentificationView(RiskBase):
                 elif k.startswith("measure-custom"):
                     _id = k.rsplit("-", 1)[-1]
                     new_custom_measures[_id] = model.ActionPlan(
-                        action=val, plan_type="in_place_custom"
+                        action=val,
+                        plan_type="in_place_custom",
+                        used_in_training=saved_in_place_custom_measures.get(_id, True),
                     )
                 # This only happens on custom risks
                 elif k.startswith("present-measure") and val.strip() != "":
                     _id = k.rsplit("-", 1)[-1]
                     if int(bool(reply.get("measure-{}".format(_id)))):
                         new_measures.append(
-                            model.ActionPlan(action=val, plan_type="in_place_custom")
+                            model.ActionPlan(
+                                action=val,
+                                plan_type="in_place_custom",
+                                used_in_training=saved_in_place_custom_measures.get(
+                                    _id, True
+                                ),
+                            )
                         )
             # Now add the custom measures in their correct order
             for k in sorted(new_custom_measures.keys()):
@@ -627,6 +769,40 @@ class IdentificationView(RiskBase):
             if new_measures:
                 self.context.action_plans.extend(new_measures)
                 changed = True
+        else:
+            # If we did not handle any measures in place, check if we need to take
+            # care of training measures that need to be activated or deactivated
+            if active_measures_in_place:
+                session.execute(
+                    "UPDATE action_plan set used_in_training=true where id in ({ids})".format(  # noqa: E501
+                        ids=",".join(active_measures_in_place)
+                    )
+                )
+                changed = True
+            if deselected_in_place_measures:
+                session.execute(
+                    "UPDATE action_plan set used_in_training=false where id in ({ids})".format(  # noqa: E501
+                        ids=",".join(deselected_in_place_measures)
+                    )
+                )
+                changed = True
+        # In case we're not dealing with an integrated action plan, de-/ activate
+        # planned measures as necessary
+        if not self.webhelpers.integrated_action_plan:
+            if active_measures_planned:
+                session.execute(
+                    "UPDATE action_plan set used_in_training=true where id in ({ids})".format(  # noqa: E501
+                        ids=",".join(active_measures_planned)
+                    )
+                )
+                changed = True
+            if deselected_planned_measures:
+                session.execute(
+                    "UPDATE action_plan set used_in_training=false where id in ({ids})".format(  # noqa: E501
+                        ids=",".join(deselected_planned_measures)
+                    )
+                )
+                changed = True
         return changed
 
     @property
@@ -658,17 +834,17 @@ class IdentificationView(RiskBase):
         self.risk_number = self.context.number
 
         self.description_probability = _(
-            u"help_default_probability",
-            default=u"Indicate how "
-            u"likely occurence of this risk is in a normal situation.",
+            "help_default_probability",
+            default="Indicate how "
+            "likely occurence of this risk is in a normal situation.",
         )
         self.description_frequency = _(
-            u"help_default_frequency",
-            default=u"Indicate how often this " u"risk occurs in a normal situation.",
+            "help_default_frequency",
+            default="Indicate how often this " "risk occurs in a normal situation.",
         )
         self.description_severity = _(
-            u"help_default_severity",
-            default=u"Indicate the " u"severity if this risk occurs.",
+            "help_default_severity",
+            default="Indicate the " "severity if this risk occurs.",
         )
 
         tool_types = self.tti()
@@ -678,9 +854,11 @@ class IdentificationView(RiskBase):
         self.show_existing_measures = False
 
         # Fill some labels with default texts
-        self.answer_yes = default_type_data["answer_yes"]
-        self.answer_no = default_type_data["answer_no"]
-        self.answer_na = default_type_data["answer_na"]
+        self.answer_yes = tool_type_data.get(
+            "answer_yes", default_type_data["answer_yes"]
+        )
+        self.answer_no = tool_type_data.get("answer_no", default_type_data["answer_no"])
+        self.answer_na = tool_type_data.get("answer_na", default_type_data["answer_na"])
         self.intro_extra = ""
         self.intro_questions = tool_type_data.get("intro_questions", "")
         if getattr(self.risk, "risk_always_present", False):
@@ -785,7 +963,7 @@ class IdentificationView(RiskBase):
                 .filter(
                     and_(
                         model.SurveyTreeItem.session == self.session,
-                        model.Module.zodb_path == u"custom-risks",
+                        model.Module.zodb_path == "custom-risks",
                     )
                 )
                 .first()
@@ -881,7 +1059,15 @@ class ImageUpload(BrowserView):
             "{}/@@identification".format(self.context.absolute_url())
         )
 
+    @property
+    @memoize
+    def webhelpers(self):
+        return api.content.get_view("webhelpers", self.context.aq_parent, self.request)
+
     def __call__(self):
+        if not self.webhelpers.can_view_session:
+            # The user cannot call this view to go the sessions overview.
+            return self.request.response.redirect(self.webhelpers.client_url)
         if self.request.form.get("image"):
             image = self.request.form["image"]
             new_data = image.read()
@@ -905,7 +1091,7 @@ class ImageUpload(BrowserView):
                 self.context.image_filename = new_name
         elif self.request.form.get("image-remove"):
             self.context.image_data = None
-            self.context.image_filename = u""
+            self.context.image_filename = ""
         return self.redirect()
 
 
@@ -916,6 +1102,11 @@ class ImageDisplay(DisplayFile):
     ../@@image-display/image_large/${here/image_filename}
     """
 
+    @property
+    @memoize
+    def webhelpers(self):
+        return api.content.get_view("webhelpers", self.context.aq_parent, self.request)
+
     def get_or_create_image_scaled(self):
         """Get the image scaled"""
         if self.context.image_data_scaled:
@@ -950,6 +1141,12 @@ class ImageDisplay(DisplayFile):
 
         return NamedBlobImage(image_data, filename=self.context.image_filename)
 
+    def __call__(self):
+        if not self.webhelpers.can_view_session:
+            # The user cannot call this view to go the sessions overview.
+            return self.request.response.redirect(self.webhelpers.client_url)
+        return super(ImageDisplay, self).__call__()
+
 
 class ActionPlanView(RiskBase):
     """Logic for creating new action plans."""
@@ -973,7 +1170,7 @@ class ActionPlanView(RiskBase):
     @property
     @memoize
     def skip_evaluation(self):
-        """ Default value is False, but it can be tweaked in certain conditions"""
+        """Default value is False, but it can be tweaked in certain conditions"""
         if self.italy_special and (
             (
                 self.risk
@@ -1091,7 +1288,7 @@ class ActionPlanView(RiskBase):
         if self.request.method == "POST":
             reply = self.request.form
             session = Session()
-            context.comment = reply.get("comment")
+            context.comment = self.webhelpers.check_markup(reply.get("comment"))
             context.priority = reply.get("priority")
 
             new_plans, changes = self.extract_plans_from_request()
@@ -1109,8 +1306,8 @@ class ActionPlanView(RiskBase):
         self.title = context.parent.title
 
         if self.is_custom_risk:
-            self.risk.description = u""
-            self.risk.evaluation_method = u""
+            self.risk.description = ""
+            self.risk.evaluation_method = ""
 
         self.image_class = IMAGE_CLASS[self.number_images]
         self.risk_number = self.context.number
@@ -1148,9 +1345,9 @@ def calculate_priority(db_risk, risk):
 def evaluation_algorithm(risk):
     for parent in aq_chain(aq_inner(risk)):
         if ISurvey.providedBy(parent):
-            return getattr(parent, "evaluation_algorithm", u"kinney")
+            return getattr(parent, "evaluation_algorithm", "kinney")
     else:
-        return u"kinney"
+        return "kinney"
 
 
 class ConfirmationDeleteRisk(BrowserView):
@@ -1158,6 +1355,11 @@ class ConfirmationDeleteRisk(BrowserView):
 
     no_splash = True
 
+    @property
+    @memoize
+    def webhelpers(self):
+        return api.content.get_view("webhelpers", self.context, self.request)
+
     @property
     def risk_title(self):
         return self.context.title
@@ -1172,6 +1374,9 @@ class ConfirmationDeleteRisk(BrowserView):
 
     def __call__(self, *args, **kwargs):
         """Before rendering check if we can find session title"""
+        if not self.webhelpers.can_view_session:
+            # The user cannot call this view to go the sessions overview.
+            return self.request.response.redirect(self.webhelpers.client_url)
         self.risk_title
         return super(ConfirmationDeleteRisk, self).__call__(*args, **kwargs)
 
@@ -1179,7 +1384,16 @@ class ConfirmationDeleteRisk(BrowserView):
 class DeleteRisk(BrowserView):
     """View name: @@delete-risk"""
 
+    @property
+    @memoize
+    def webhelpers(self):
+        return api.content.get_view("webhelpers", self.context, self.request)
+
     def __call__(self):
+        if not self.webhelpers.can_view_session:
+            # The user cannot call this view to go the sessions overview.
+            return self.request.response.redirect(self.webhelpers.client_url)
+
         risk_id = self.request.form.get("risk_id", None)
         if risk_id:
             try:
