@@ -30,6 +30,7 @@ from plone.app.event.base import localized_now
 from plone.autoform.form import AutoExtensibleForm
 from plone.memoize.view import memoize
 from plone.memoize.view import memoize_contextless
+from plone.protect.utils import addTokenToUrl
 from plone.supermodel import model
 from Products.CMFPlone import PloneLocalesMessageFactory
 from Products.Five import BrowserView
@@ -75,20 +76,20 @@ def sql_clone(obj, skip={}, session=None):
 class IStartFormSchema(model.Schema):
     title = schema.TextLine(
         title=_(
-            "label_session_title", default=u"Enter a title for your Risk Assessment"
+            "label_session_title", default="Enter a title for your Risk Assessment"
         ),
         required=True,
         description=_(
             "session_title_tooltip",
-            default=u"Once you have started an OiRA tool "
-            u"session, you will be able to stop before the end. You can restart it "
-            u"again at a later date by selecting the title of the OiRA tool session. "
-            u"You can save more than one session, provided you have given them "
-            u"different title names. Please remember your e-mail address, password "
-            u"and the title that you have given the OiRA tool session. By clicking "
-            u"on the Logout button, you are logged out actively. You are also logged "
-            u"out if you close your Browser. For security reasons it is better to "
-            u"actively log out.",
+            default="Once you have started an OiRA tool "
+            "session, you will be able to stop before the end. You can restart it "
+            "again at a later date by selecting the title of the OiRA tool session. "
+            "You can save more than one session, provided you have given them "
+            "different title names. Please remember your e-mail address, password "
+            "and the title that you have given the OiRA tool session. By clicking "
+            "on the Logout button, you are logged out actively. You are also logged "
+            "out if you close your Browser. For security reasons it is better to "
+            "actively log out.",
         ),
     )
 
@@ -161,7 +162,7 @@ class Start(SessionMixin, AutoExtensibleForm, EditForm):
     ignoreContext = True
     schema = IStartFormSchema
     variation_class = "variation-risk-assessment"
-    data_pat_autosubmit = "delay: 2000ms"
+    data_pat_autosubmit = ""
 
     @property
     def template(self):
@@ -169,7 +170,7 @@ class Start(SessionMixin, AutoExtensibleForm, EditForm):
 
     @property
     def message_gt1(self):
-        return api.portal.translate(_(u"This value must be greater than or equal to 1"))
+        return api.portal.translate(_("This value must be greater than or equal to 1"))
 
     @memoize
     def get_pat_messages_above_title(self):
@@ -177,14 +178,14 @@ class Start(SessionMixin, AutoExtensibleForm, EditForm):
         if not self.webhelpers.can_edit_session:
             link_download_section = _(
                 "no_translate_link_download_section",
-                default=u"<a href='%s/@@report'>${text_download_section}</a>"
+                default="<a href='%s/@@report'>${text_download_section}</a>"
                 % self.context.absolute_url(),
-                mapping={"text_download_section": _(u"download section")},
+                mapping={"text_download_section": _("download section")},
             )
             message = _(
-                u"You don't have edit rights for this risk assesment, "
-                u"but you can download "
-                u"this risk assessment in various forms in the ${download_section}.",
+                "You don't have edit rights for this risk assesment, "
+                "but you can download "
+                "this risk assessment in various forms in the ${download_section}.",
                 mapping={"download_section": link_download_section},
             )
             return [api.portal.translate(message)]
@@ -195,12 +196,14 @@ class Start(SessionMixin, AutoExtensibleForm, EditForm):
         """List of messages we want to display under the risk assesment article
 
         Those messages should be iterable.
-        Example of a good returned value:
-        [
-            (message1a, message1b, message1c),
-            (message2a, message2),
-            ...
-        ]
+        Example of a good returned value::
+
+            [
+                (message1a, message1b, message1c),
+                (message2a, message2),
+                ...
+            ]
+
         """
         return []
 
@@ -227,7 +230,7 @@ class Start(SessionMixin, AutoExtensibleForm, EditForm):
         # show the "start" page again
         if "form.button.submit" in self.request:
             return self.request.response.redirect(
-                "%s/@@profile" % self.context.absolute_url()
+                addTokenToUrl("%s/@@profile" % self.context.absolute_url())
             )
 
 
@@ -377,17 +380,17 @@ class Profile(SessionMixin, AutoExtensibleForm, EditForm):
                 "label_multiple_present": getattr(
                     child,
                     "label_multiple_present",
-                    _(u"Does this happen in multiple places?"),
+                    _("Does this happen in multiple places?"),
                 ),
                 "label_single_occurance": getattr(
                     child,
                     "label_single_occurance",
-                    _(u"Enter the name of the location"),
+                    _("Enter the name of the location"),
                 ),
                 "label_multiple_occurances": getattr(
                     child,
                     "label_multiple_occurances",
-                    _(u"Enter the names of each location"),
+                    _("Enter the names of each location"),
                 ),
             }
             for child in self.context.ProfileQuestions()
@@ -438,6 +441,10 @@ class Involve(SessionMixin, BrowserView):
         )
 
     def __call__(self):
+        if not self.webhelpers.can_view_session:
+            # The user cannot call this view, to go the sessions overview.
+            return self.request.response.redirect(self.webhelpers.client_url)
+
         utils.setLanguage(self.request, self.survey, self.survey.language)
         return super(Involve, self).__call__()
 
@@ -453,11 +460,11 @@ class ContentsPreview(BrowserView):
     @property
     def extra_text(self):
         have_extra = api.portal.get_registry_record(
-            "euphorie.extra_text_identification", default=u""
+            "euphorie.extra_text_identification", default=""
         )
         if not have_extra:
             return None
-        return api.portal.translate(_(u"extra_text_identification", default=u""))
+        return api.portal.translate(_("extra_text_identification", default=""))
 
     @property
     @memoize
@@ -466,7 +473,7 @@ class ContentsPreview(BrowserView):
 
     @property
     def title_custom_risks(self):
-        return api.portal.translate(_("label_custom_risks", default=u"Custom risks"))
+        return api.portal.translate(_("label_custom_risks", default="Custom risks"))
 
     def get_session_nodes(self):
         """Return an ordered list of all tree items for the current survey.
@@ -492,6 +499,14 @@ class ContentsPreview(BrowserView):
         else:
             return node.title
 
+    def get_description(self, node):
+        if node.zodb_path.find("custom-risks") > -1:
+            risk = Session.query(Risk).filter(Risk.id == node.id).first()
+            if risk:
+                return risk.custom_description
+        else:
+            return self.zodb_node(node).description
+
     def get_legal_references(self, node):
         """We might add some logic to never show legal references depending
         on a setting per country / survey.
@@ -511,7 +526,7 @@ class ContentsPreview(BrowserView):
             if not ISolution.providedBy(solution):
                 continue
             if mode == "full":
-                text = u"{title}<br/>{description}".format(
+                text = "{title}<br/>{description}".format(
                     title=solution.description, description=solution.action
                 )
             else:
@@ -573,7 +588,7 @@ class Identification(SessionMixin, BrowserView):
     @property
     def extra_text(self):
         have_extra = api.portal.get_registry_record(
-            "euphorie.extra_text_identification", default=u""
+            "euphorie.extra_text_identification", default=""
         )
         if not have_extra:
             return None
@@ -585,7 +600,7 @@ class Identification(SessionMixin, BrowserView):
             elems = lang.split("-")
             lang = "{0}_{1}".format(elems[0], elems[1].upper())
         return translate(
-            _(u"extra_text_identification", default=u""), target_language=lang
+            _("extra_text_identification", default=""), target_language=lang
         )
 
     def __call__(self):
@@ -618,7 +633,7 @@ class DeleteSession(SessionMixin, BrowserView):
         Session.delete(self.context.session)
         api.portal.show_message(
             _(
-                u"Session `${name}` has been deleted.",
+                "Session `${name}` has been deleted.",
                 mapping={"name": self.context.session.title},
             ),
             self.request,
@@ -671,7 +686,7 @@ class ArchiveSession(SessionMixin, BrowserView):
         session.archived = localized_now()
         self.notify_modified()
         api.portal.show_message(
-            _(u"Session `${name}` has been archived.", mapping={"name": session.title}),
+            _("Session `${name}` has been archived.", mapping={"name": session.title}),
             self.request,
             "success",
         )
@@ -699,8 +714,8 @@ class CloneSession(SessionMixin, BrowserView):
             session=sql_session,
         )
         lang = getattr(self.request, "LANGUAGE", "en")
-        new_session.title = u"{}: {}".format(
-            translate(_("prefix_cloned_title", default=u"COPY"), target_language=lang),
+        new_session.title = "{}: {}".format(
+            translate(_("prefix_cloned_title", default="COPY"), target_language=lang),
             new_session.title,
         )
         account = self.webhelpers.get_current_account()
@@ -753,6 +768,10 @@ class CloneSession(SessionMixin, BrowserView):
 
     def clone(self):
         """Clone this session and redirect to the start view"""
+        if not self.webhelpers.can_view_session:
+            # The user cannot call this view to go the sessions overview.
+            return self.request.response.redirect(self.webhelpers.client_url)
+
         new_session = self.get_cloned_session()
         api.portal.show_message(
             _("The risk assessment has been cloned"), self.request, "success"
@@ -762,6 +781,12 @@ class CloneSession(SessionMixin, BrowserView):
         )
         self.request.response.redirect(target)
 
+    def __call__(self):
+        if not self.webhelpers.can_view_session:
+            # The user cannot call this view to go the sessions overview.
+            return self.request.response.redirect(self.webhelpers.client_url)
+        return super(CloneSession, self).__call__()
+
 
 class PublicationMenu(SessionMixin, BrowserView):
     @property
@@ -918,7 +943,7 @@ class Status(SessionMixin, BrowserView, _StatusHelper):
             date_lang = lang.split("-")[0]
             elems = lang.split("-")
             lang = "{0}_{1}".format(elems[0], elems[1].upper())
-        self.date = u"{0} {1} {2}".format(
+        self.date = "{0} {1} {2}".format(
             now.strftime("%d"),
             translate(
                 PloneLocalesMessageFactory(
@@ -1160,7 +1185,7 @@ class MeasuresOverview(Status):
                 number = module.number
                 if "custom-risks" in module.zodb_path:
                     num_elems = number.split(".")
-                    number = u".".join([u"Ω"] + num_elems[1:])
+                    number = ".".join(["Ω"] + num_elems[1:])
                     title = api.portal.translate(_(title))
                 main_modules[path] = {"name": title, "number": number, "risks": risks}
 
