@@ -99,8 +99,7 @@ class WebHelpers(BrowserView):
     css_path = "++resource++euphorie.resources/{brand}/style/all.css"
     css_path_min = "++resource++euphorie.resources/{brand}/style/all.css"
 
-    js_name = "bundle.js"
-    js_name_min = "bundle.min.js"
+    js_name = "bundle.min.js"
 
     favicon_path = "++resource++euphorie.resources/{brand}/favicon/apple-touch-icon.png"
 
@@ -166,9 +165,13 @@ class WebHelpers(BrowserView):
     @property
     @memoize
     def use_training_module(self):
-        return api.portal.get_registry_record(
+        globally_enabled = api.portal.get_registry_record(
             "euphorie.use_training_module", default=False
         )
+        if not globally_enabled:
+            return False
+        country_enabled = self.content_country_obj.enable_web_training
+        return country_enabled
 
     @property
     @memoize
@@ -177,6 +180,11 @@ class WebHelpers(BrowserView):
             "euphorie.use_publication_feature", default=False
         )
 
+    @memoize
+    def use_publication_feature_for_session(self, session):
+        # to be overwritten as needed
+        return self.use_publication_feature
+
     @property
     @memoize
     def use_clone_feature(self):
@@ -205,7 +213,7 @@ class WebHelpers(BrowserView):
     @property
     @memoize
     def default_country(self):
-        return api.portal.get_registry_record("euphorie.default_country", default=u"")
+        return api.portal.get_registry_record("euphorie.default_country", default="")
 
     @property
     @memoize
@@ -307,21 +315,30 @@ class WebHelpers(BrowserView):
             completion_percentage = self.traversed_session.session.completion_percentage
         title = _(
             "progress_indicator_title",
-            default=u"${completion_percentage}% Complete",
+            default="${completion_percentage}% Complete",
             mapping={"completion_percentage": completion_percentage or 0},
         )
         return api.portal.translate(title)
 
+    @memoize
+    def get_came_from(self, default=None):
+        came_from = self.request.form.get("came_from")
+        if not came_from:
+            return default
+        if isinstance(came_from, list):
+            # If came_from is both in the querystring and the form data
+            came_from = came_from[0]
+        put = getToolByName(self.context, "portal_url")
+        if came_from and not put.isURLInPortal(came_from):
+            return default
+        return came_from
+
     @property
     @memoize
     def came_from(self):
-        came_from = self.request.form.get("came_from")
-        if not came_from:
-            return aq_parent(self.context).absolute_url()
-        if not isinstance(came_from, list):
-            return came_from
-        # If came_from is both in the querystring and the form data
-        return came_from[0]
+        default = aq_parent(self.context).absolute_url()
+        came_from = self.get_came_from(default=default)
+        return came_from
 
     @property
     @memoize
@@ -457,12 +474,16 @@ class WebHelpers(BrowserView):
     def logoMode(self):
         return "alien" if "alien" in self.extra_css else "native"
 
+    def check_markup(self, text):
+        if StripMarkup(text).strip():
+            return text
+
     @property
     @memoize
     def extra_css(self):
         sector = self.sector
         if sector is None:
-            return u""
+            return ""
 
         sector = aq_base(sector)
         parts = []
@@ -488,7 +509,7 @@ class WebHelpers(BrowserView):
         else:
             return _(
                 "title_tool",
-                default=u"OiRA - Online interactive Risk Assessment",
+                default="OiRA - Online interactive Risk Assessment",
             )
 
     @property
@@ -576,7 +597,7 @@ class WebHelpers(BrowserView):
         return "{}/{}/{}?t={}".format(
             self.client_url,
             self.script_path,
-            self.js_name if not self.debug_mode else self.js_name_min,
+            self.js_name,
             self.resources_timestamp,
         )
 
@@ -814,12 +835,20 @@ class WebHelpers(BrowserView):
         sector = self.sector
         if sector is None:
             return None
-        images = getMultiAdapter((sector, self.request), name="images")
+        real_sector = sector._sector()
+        images = getMultiAdapter((real_sector, self.request), name="images")
         try:
-            return images.scale("logo", height=100, direction="up") or None
+            return images.scale("logo", height=400, direction="up") or None
         except POSKeyError:
             return None
 
+    @memoize
+    def get_tool_image_url(self, survey=None):
+        if not survey:
+            survey = self._survey
+        if getattr(survey, "image", None):
+            return f"{survey.absolute_url()}/@@images/image/large"
+
     def messages(self):
         status = IStatusMessage(self.request)
         messages = status.show()
@@ -881,10 +910,10 @@ class WebHelpers(BrowserView):
         return message
 
     def closetext(self):
-        return api.portal.translate(_(u"button_close", default=u"Close"))
+        return api.portal.translate(_("button_close", default="Close"))
 
     def email_sharing_text(self):
-        return api.portal.translate(_(u"I wish to share the following with you"))
+        return api.portal.translate(_("I wish to share the following with you"))
 
     def getSecret(self):
         return getSecret()
@@ -953,7 +982,7 @@ class WebHelpers(BrowserView):
 
     def as_md(self, text):
         """Return a text with Carriage Returns formatted as a Markdown."""
-        return u"\r\n".join([x for x in text.split("\r")])
+        return "\r\n".join([x for x in text.split("\r")])
 
     def show_logo(self):
         """In plain Euphorie, the logo is always shown"""
@@ -965,6 +994,8 @@ class WebHelpers(BrowserView):
         return api.portal.get_tool("portal_transforms")
 
     def get_safe_html(self, text):
+        if not text:
+            return
         data = self.portal_transforms.convertTo(
             "text/x-html-safe", text, mimetype="text/html"
         )
