@@ -69,18 +69,18 @@ class find_sql_context_tests(EuphorieIntegrationTestCase):
 
     def createSqlData(self):
         self.session = Session()
-        account = model.Account(loginname=u"jane", password=u"secret")
+        account = model.Account(loginname="jane", password="secret")
         self.session.add(account)
         self.survey = model.SurveySession(
-            title=u"Survey", zodb_path="survey", account=account
+            title="Survey", zodb_path="survey", account=account
         )
         self.session.add(self.survey)
         self.session.flush()
         self.mod1 = self.survey.addChild(
-            model.Module(title=u"module 1", module_id="1", zodb_path="a")
+            model.Module(title="module 1", module_id="1", zodb_path="a")
         )
         self.q1 = self.mod1.addChild(
-            model.Risk(title=u"question 1", risk_id="1", zodb_path="a/b")
+            model.Risk(title="question 1", risk_id="1", zodb_path="a/b")
         )
         self.session.flush()
 
@@ -114,10 +114,10 @@ class find_sql_context_tests(EuphorieIntegrationTestCase):
 
     def test_keep_sessions_apart(self):
         self.createSqlData()
-        account = model.Account(loginname=u"john", password=u"jane")
+        account = model.Account(loginname="john", password="jane")
         self.session.add(account)
         survey2 = model.SurveySession(
-            title=u"Survey", zodb_path="survey", account=account
+            title="Survey", zodb_path="survey", account=account
         )
         self.session.add(survey2)
         self.session.flush()
@@ -132,18 +132,18 @@ class build_tree_aq_chain_tests(EuphorieIntegrationTestCase):
 
     def createSqlData(self):
         self.session = Session()
-        account = model.Account(loginname=u"jane", password=u"secret")
+        account = model.Account(loginname="jane", password="secret")
         self.session.add(account)
         self.survey = model.SurveySession(
-            title=u"Survey", zodb_path="survey", account=account
+            title="Survey", zodb_path="survey", account=account
         )
         self.session.add(self.survey)
         self.session.flush()
         self.mod1 = self.survey.addChild(
-            model.Module(title=u"module 1", module_id="1", zodb_path="a")
+            model.Module(title="module 1", module_id="1", zodb_path="a")
         )
         self.q1 = self.mod1.addChild(
-            model.Risk(title=u"question 1", risk_id="1", zodb_path="a/b")
+            model.Risk(title="question 1", risk_id="1", zodb_path="a/b")
         )
         self.session.flush()
 
@@ -171,10 +171,10 @@ class completion_percentage_tests(EuphorieIntegrationTestCase):
     def setUp(self):
         super(completion_percentage_tests, self).setUp()
         self.session = Session()
-        account = model.Account(loginname=u"jane", password=u"secret")
+        account = model.Account(loginname="jane", password="secret")
         self.session.add(account)
         self.survey = model.SurveySession(
-            title=u"Survey", zodb_path="survey", account=account
+            title="Survey", zodb_path="survey", account=account
         )
         self.session.add(self.survey)
         self.session.flush()
@@ -186,13 +186,13 @@ class completion_percentage_tests(EuphorieIntegrationTestCase):
 
     def test_half_complete(self):
         self.mod1 = self.survey.addChild(
-            model.Module(title=u"module 1", module_id="1", zodb_path="a")
+            model.Module(title="module 1", module_id="1", zodb_path="a")
         )
         self.q1 = self.mod1.addChild(
-            model.Risk(title=u"question 1", risk_id="1", zodb_path="a/b")
+            model.Risk(title="question 1", risk_id="1", zodb_path="a/b")
         )
         self.q2 = self.mod1.addChild(
-            model.Risk(title=u"question 2", risk_id="2", zodb_path="a/c")
+            model.Risk(title="question 2", risk_id="2", zodb_path="a/c")
         )
         self.session.flush()
 
@@ -205,19 +205,19 @@ class completion_percentage_tests(EuphorieIntegrationTestCase):
 
     def test_two_thirds_complete(self):
         self.mod1 = self.survey.addChild(
-            model.Module(title=u"module 1", module_id="1", zodb_path="a")
+            model.Module(title="module 1", module_id="1", zodb_path="a")
         )
         self.q1 = self.mod1.addChild(
-            model.Risk(title=u"question 1", risk_id="1", zodb_path="a/b")
+            model.Risk(title="question 1", risk_id="1", zodb_path="a/b")
         )
         self.q2 = self.mod1.addChild(
-            model.Risk(title=u"question 2", risk_id="2", zodb_path="a/c")
+            model.Risk(title="question 2", risk_id="2", zodb_path="a/c")
         )
         self.mod2 = self.survey.addChild(
-            model.Module(title=u"module 2", module_id="2", zodb_path="k")
+            model.Module(title="module 2", module_id="2", zodb_path="k")
         )
         self.q21 = self.mod1.addChild(
-            model.Risk(title=u"question 3", risk_id="3", zodb_path="k/l")
+            model.Risk(title="question 3", risk_id="3", zodb_path="k/l")
         )
         self.session.flush()
 
@@ -232,16 +232,16 @@ class completion_percentage_tests(EuphorieIntegrationTestCase):
 
     def test_optional_module(self):
         self.mod1 = self.survey.addChild(
-            model.Module(title=u"module 1", module_id="1", zodb_path="a")
+            model.Module(title="module 1", module_id="1", zodb_path="a")
         )
         self.q1 = self.mod1.addChild(
-            model.Risk(title=u"question 1", risk_id="1", zodb_path="a/b")
+            model.Risk(title="question 1", risk_id="1", zodb_path="a/b")
         )
         self.mod2 = self.survey.addChild(
-            model.Module(title=u"module 2", module_id="2", zodb_path="k")
+            model.Module(title="module 2", module_id="2", zodb_path="k")
         )
         self.q2 = self.mod2.addChild(
-            model.Risk(title=u"question 2", risk_id="2", zodb_path="k/c")
+            model.Risk(title="question 2", risk_id="2", zodb_path="k/c")
         )
         self.q1.postponed = False
         self.q1.identification = "yes"
@@ -253,19 +253,19 @@ class completion_percentage_tests(EuphorieIntegrationTestCase):
 
     def test_optional_submodule(self):
         self.mod1 = self.survey.addChild(
-            model.Module(title=u"module 1", module_id="1", zodb_path="a")
+            model.Module(title="module 1", module_id="1", zodb_path="a")
         )
         self.q1 = self.mod1.addChild(
-            model.Risk(title=u"question 1", risk_id="1", zodb_path="a/b")
+            model.Risk(title="question 1", risk_id="1", zodb_path="a/b")
         )
         self.mod2 = self.survey.addChild(
-            model.Module(title=u"module 2", module_id="2", zodb_path="k")
+            model.Module(title="module 2", module_id="2", zodb_path="k")
         )
         self.mod21 = self.mod2.addChild(
-            model.Module(title=u"module 3", module_id="3", zodb_path="k/c")
+            model.Module(title="module 3", module_id="3", zodb_path="k/c")
         )
         self.q2 = self.mod21.addChild(
-            model.Risk(title=u"question 2", risk_id="2", zodb_path="k/c/u")
+            model.Risk(title="question 2", risk_id="2", zodb_path="k/c/u")
         )
         self.q1.postponed = False
         self.q1.identification = "yes"
@@ -277,19 +277,19 @@ class completion_percentage_tests(EuphorieIntegrationTestCase):
 
     def test_optional_module_with_submodule(self):
         self.mod1 = self.survey.addChild(
-            model.Module(title=u"module 1", module_id="1", zodb_path="a")
+            model.Module(title="module 1", module_id="1", zodb_path="a")
         )
         self.q1 = self.mod1.addChild(
-            model.Risk(title=u"question 1", risk_id="1", zodb_path="a/b")
+            model.Risk(title="question 1", risk_id="1", zodb_path="a/b")
         )
         self.mod2 = self.survey.addChild(
-            model.Module(title=u"module 2", module_id="2", zodb_path="k")
+            model.Module(title="module 2", module_id="2", zodb_path="k")
         )
         self.mod21 = self.mod2.addChild(
-            model.Module(title=u"module 3", module_id="3", zodb_path="k/c")
+            model.Module(title="module 3", module_id="3", zodb_path="k/c")
         )
         self.q2 = self.mod21.addChild(
-            model.Risk(title=u"question 2", risk_id="2", zodb_path="k/c/u")
+            model.Risk(title="question 2", risk_id="2", zodb_path="k/c/u")
         )
 
         self.q1.postponed = False
