@@ -17,7 +17,7 @@ from euphorie.content import MessageFactory as _
 from euphorie.content.behaviors.toolcategory import IToolCategory
 from euphorie.content.utils import IToolTypesInfo
 from io import BytesIO
-from plone import api
+from markdownify import markdownify
 from plone.autoform.form import AutoExtensibleForm
 from plone.dexterity.utils import createContentInContainer
 from plone.namedfile import field as filefield
@@ -58,14 +58,22 @@ COMMA_REPLACEMENT = "__COMMA__"
 
 
 def attr_unicode(node, attr, default=None):
-    value = six.text_type(node.attrib.get(attr, u"")).strip()
+    value = six.text_type(node.attrib.get(attr, "")).strip()
     if not value:
         return default
     return value
 
 
+def attr_string(node, tag, attr, default=None):
+    value = default
+    element = getattr(node, tag, None)
+    if element is not None:
+        value = element.attrib.get(attr)
+    return value
+
+
 def attr_vocabulary(node, tag, field, default=None):
-    value = node.get(tag, u"").strip() if node else None
+    value = node.get(tag, "").strip() if node else None
     if not value:
         return default
     try:
@@ -74,11 +82,32 @@ def attr_vocabulary(node, tag, field, default=None):
         return default
 
 
-def el_unicode(node, tag, default=None):
+def attr_bool(node, tag, attr, default=False):
+    value = default
+    element = getattr(node, tag, None)
+    if element is not None:
+        value = element.get(attr)
+    return value == "true"
+
+
+def el_unicode(
+    node, tag, default=None, is_etranslate_compatible=False, convert_to_markdown=False
+):
     value = getattr(node, tag, None)
     if value is None:
         return default
-    return six.text_type(value)
+    if is_etranslate_compatible:
+        # We need to remove the outer XML element e.g. <description>
+        wrapped_xml = lxml.etree.tostring(value, encoding="unicode", pretty_print=True)
+        end_of_first_tag = wrapped_xml.find(">") + 1
+        start_of_last_tag = wrapped_xml.rfind("<")
+        unwrapped_html = wrapped_xml[end_of_first_tag:start_of_last_tag]
+        if convert_to_markdown:
+            return markdownify(unwrapped_html)
+        else:
+            return unwrapped_html
+    else:
+        return six.text_type(value)
 
 
 def el_string(node, tag, default=None):
@@ -99,39 +128,38 @@ class IImportSector(Interface):
     """The fields used for importing a :obj:`euphorie.content.sector`."""
 
     sector_title = schema.TextLine(
-        title=_("label_sector_title", default=u"Title of sector."),
+        title=_("label_sector_title", default="Title of sector."),
         description=_(
             "help_sector_title",
-            default=u"If you do not specify a title it will be taken "
-            u"from the input file.",
+            default="If you do not specify a title it will be taken "
+            "from the input file.",
         ),
         required=False,
     )
 
     sector_login = LoginField(
-        title=_("label_login_name", default=u"Login name"),
+        title=_("label_login_name", default="Login name"),
         required=True,
         constraint=validLoginValue,
     )
 
     surveygroup_title = schema.TextLine(
-        title=_("label_surveygroup_title", default=u"Title of imported OiRA Tool"),
+        title=_("label_surveygroup_title", default="Title of imported OiRA Tool"),
         description=_(
             "help_upload_surveygroup_title",
-            default=u"If you do not specify a title it will be taken "
-            u"from the input.",
+            default="If you do not specify a title it will be taken " "from the input.",
         ),
         required=False,
     )
 
     survey_title = schema.TextLine(
-        title=_("label_upload_survey_title", default=u"Name for OiRA Tool version"),
-        default=_(u"Standard"),
+        title=_("label_upload_survey_title", default="Name for OiRA Tool version"),
+        default=_("Standard"),
         required=True,
     )
 
     file = filefield.NamedFile(
-        title=_("label_upload_filename", default=u"XML file"), required=True
+        title=_("label_upload_filename", default="XML file"), required=True
     )
 
 
@@ -139,23 +167,31 @@ class IImportSurvey(Interface):
     """The fields used for importing a :obj:`euphorie.content.survey`."""
 
     surveygroup_title = schema.TextLine(
-        title=_("label_surveygroup_title", default=u"Title of imported OiRA Tool"),
+        title=_("label_surveygroup_title", default="Title of imported OiRA Tool"),
         description=_(
             "help_upload_surveygroup_title",
-            default=u"If you do not specify a title it will be taken "
-            u"from the input.",
+            default="If you do not specify a title it will be taken " "from the input.",
         ),
         required=False,
     )
 
     survey_title = schema.TextLine(
-        title=_("label_upload_survey_title", default=u"Name for OiRA Tool version"),
-        default=_(u"OiRA Tool import"),
+        title=_("label_upload_survey_title", default="Name for OiRA Tool version"),
+        default=_("OiRA Tool import"),
         required=True,
     )
 
     file = filefield.NamedFile(
-        title=_("label_upload_filename", default=u"XML file"), required=True
+        title=_("label_upload_filename", default="XML file"), required=True
+    )
+
+    is_etranslate_compatible = schema.Bool(
+        title=_(
+            "label_is_etranslate_compatible",
+            default="Import XML translation from eTranslate",
+        ),
+        required=False,
+        default=False,
     )
 
 
@@ -164,11 +200,10 @@ class SurveyImporter(object):
     and survey. This assumes the current context is a sector.
     """
 
+    is_etranslate_compatible = False
+
     def __init__(self, context):
         self.context = context
-        self.use_existing_measures = api.portal.get_registry_record(
-            "euphorie.use_existing_measures"
-        )
 
     def ImportImage(self, node):
         """
@@ -180,11 +215,11 @@ class SurveyImporter(object):
         filename = attr_unicode(node, "filename")
         contentType = node.get("content-type", None)
         if not filename:
-            basename = u"image%d.%%s" % random.randint(1, 2 ** 16)
+            basename = "image%d.%%s" % random.randint(1, 2**16)
             if contentType and "/" in contentType:
-                filename = basename % contentType.split(u"/")[1]
+                filename = basename % contentType.split("/")[1]
             else:
-                filename = basename % u"jpg"
+                filename = basename % "jpg"
         image = NamedBlobImage(
             data=decodebytes(safe_bytes(str(node.text))),
             contentType=contentType,
@@ -204,9 +239,13 @@ class SurveyImporter(object):
         """
         solution = createContentInContainer(risk, "euphorie.solution")
         solution.description = six.text_type(node.description)
-        solution.action = six.text_type(
-            getattr(node, "action", None) or node.description
+        action = el_unicode(
+            node,
+            "action",
+            is_etranslate_compatible=self.is_etranslate_compatible,
+            convert_to_markdown=True,
         )
+        solution.action = action or node.description
         solution.action_plan = six.text_type(getattr(node, "action-plan", ""))
         solution.prevention_plan = el_unicode(node, "prevention-plan")
         solution.requirements = el_unicode(node, "requirements")
@@ -226,20 +265,24 @@ class SurveyImporter(object):
         )
         EnsureInterface(risk)
         risk.type = node.get("type")
-        risk.description = six.text_type(getattr(node, "description", ""))
-        risk.problem_description = el_unicode(node, "problem-description")
+        risk.description = el_unicode(
+            node, "description", is_etranslate_compatible=self.is_etranslate_compatible
+        )
+        risk.problem_description = el_unicode(
+            node,
+            "problem-description",
+            is_etranslate_compatible=self.is_etranslate_compatible,
+        )
         risk.legal_reference = el_unicode(node, "legal-reference")
         risk.show_notapplicable = el_bool(node, "show-not-applicable")
         risk.external_id = attr_unicode(node, "external-id")
-        if self.use_existing_measures:
-            risk.existing_measures = el_unicode(node, "existing_measures")
 
         if risk.type == "risk":
             em = getattr(node, "evaluation-method", None)
             risk.evaluation_method = em.text if em else "estimated"
             if risk.evaluation_method == "calculated":
                 evaluation_algorithm = risk.evaluation_algorithm()
-                if evaluation_algorithm == u"kinney":
+                if evaluation_algorithm == "kinney":
                     risk.default_probability = attr_vocabulary(
                         em,
                         "default-probability",
@@ -251,7 +294,7 @@ class SurveyImporter(object):
                     risk.default_effect = attr_vocabulary(
                         em, "default-effect", IKinneyEvaluation["default_effect"]
                     )
-                elif evaluation_algorithm == u"french":
+                elif evaluation_algorithm == "french":
                     risk.default_severity = attr_vocabulary(
                         em, "default-severity", IFrenchEvaluation["default_severity"]
                     )
@@ -288,7 +331,9 @@ class SurveyImporter(object):
             survey, "euphorie.module", title=six.text_type(node.title)
         )
         module.optional = node.get("optional") == "true"
-        module.description = el_unicode(node, "description")
+        module.description = el_unicode(
+            node, "description", is_etranslate_compatible=self.is_etranslate_compatible
+        )
         module.external_id = attr_unicode(node, "external-id")
         if module.optional:
             module.question = six.text_type(node.question)
@@ -325,7 +370,9 @@ class SurveyImporter(object):
             profile = createContentInContainer(
                 survey, "euphorie.profilequestion", title=six.text_type(node.title)
             )
-        profile.description = el_unicode(node, "description")
+        profile.description = el_unicode(
+            node, "description", is_etranslate_compatible=self.is_etranslate_compatible
+        )
         profile.question = six.text_type(node.question)
         profile.external_id = attr_unicode(node, "external-id")
         for fname in ProfileQuestionLocationFields:
@@ -348,21 +395,39 @@ class SurveyImporter(object):
         :returns: :obj:`euphorie.content.survey`.
         """
         survey = createContentInContainer(group, "euphorie.survey", title=version_title)
-        survey.introduction = el_unicode(node, "introduction")
+        survey.introduction = el_unicode(
+            node, "introduction", is_etranslate_compatible=self.is_etranslate_compatible
+        )
         survey.classification_code = el_unicode(node, "classification-code")
         survey.language = el_string(node, "language")
         tti = getUtility(IToolTypesInfo)
-        survey.tool_type = el_string(node, "tool_type", tti.default_tool_type)
-        survey.measures_text_handling = el_string(
-            node, "measures_text_handling", "full"
-        )
-        survey.integrated_action_plan = el_bool(node, "integrated_action_plan")
-        survey.evaluation_optional = el_bool(node, "evaluation-optional")
+        if self.is_etranslate_compatible:
+            survey.tool_type = attr_string(
+                node, "tool_type", "value", tti.default_tool_type
+            )
+            survey.measures_text_handling = attr_string(
+                node, "measures_text_handling", "value", "full"
+            )
+            survey.integrated_action_plan = attr_bool(
+                node, "integrated_action_plan", "value"
+            )
+            survey.evaluation_optional = attr_bool(node, "evaluation-optional", "value")
+        else:
+            survey.tool_type = el_string(node, "tool_type", tti.default_tool_type)
+            survey.measures_text_handling = el_string(
+                node, "measures_text_handling", "full"
+            )
+            survey.integrated_action_plan = el_bool(node, "integrated_action_plan")
+            survey.evaluation_optional = el_bool(node, "evaluation-optional")
         survey.external_id = attr_unicode(node, "external-id")
-        external_site_logo = getattr(node, "image", None)
+        external_site_logo = getattr(node, "external_site_logo", None)
         if external_site_logo is not None:
             (image, caption) = self.ImportImage(external_site_logo)
             survey.external_site_logo = image
+        lead_image = getattr(node, "image", None)
+        if lead_image is not None:
+            (image, caption) = self.ImportImage(lead_image)
+            survey.image = image
 
         if IToolCategory.providedBy(survey):
             IToolCategory(survey).tool_category = [
@@ -376,13 +441,16 @@ class SurveyImporter(object):
                 self.ImportModule(child, survey)
         return survey
 
-    def __call__(self, input, surveygroup_title, survey_title):
+    def __call__(
+        self, input, surveygroup_title, survey_title, is_etranslate_compatible=False
+    ):
         """Import a new survey from the XML data in `input` and create a
         new survey with the given `title`.
 
         `input` has to be either the raw XML input, or a `lxml.objectify`
         enablde DOM.
         """
+        self.is_etranslate_compatible = is_etranslate_compatible
         if isinstance(input, six.string_types + (bytes,)):
             try:
                 sector = lxml.objectify.fromstring(safe_bytes(input))
@@ -458,27 +526,32 @@ class ImportSurvey(AutoExtensibleForm, form.Form):
 
     schema = IImportSurvey
     ignoreContext = True
-    form_name = _(u"Import OiRA Tool version")
+    form_name = _("Import OiRA Tool version")
 
     importer_factory = SurveyImporter
 
-    @button.buttonAndHandler(_(u"Upload"))
+    @button.buttonAndHandler(_("Upload"))
     def handleUpload(self, action):
         (data, errors) = self.extractData()
         input = data["file"].data
         importer = self.importer_factory(self.context)
         try:
-            survey = importer(input, data["surveygroup_title"], data["survey_title"])
+            survey = importer(
+                input,
+                data["surveygroup_title"],
+                data["survey_title"],
+                data["is_etranslate_compatible"],
+            )
         except lxml.etree.XMLSyntaxError:
             raise WidgetActionExecutionError(
                 "file",
                 Invalid(
-                    _("error_invalid_xml", default=u"Please upload a valid XML file")
+                    _("error_invalid_xml", default="Please upload a valid XML file")
                 ),
             )
 
         IStatusMessage(self.request).addStatusMessage(
-            _("upload_success", default=u"Succesfully imported the OiRA Tool"),
+            _("upload_success", default="Succesfully imported the OiRA Tool"),
             type="success",
         )
         state = getMultiAdapter((survey, self.request), name="plone_context_state")
